within ;
package PhysioSystem
  model CVS
    Physiolibrary.Hydraulic.Components.Conductor PulmonaryConductance(
        useConductanceInput=false, Conductance=6.9755726553646e-08) annotation
      (Placement(visible=true, transformation(
          origin={-30,36},
          extent={{-10,-10},{10,10}},
          rotation=0)));
    Physiolibrary.Hydraulic.Components.ElasticVessel PulmonaryArtE(                                          ZeroPressureVolume = 0,
      volume_start=0.0001,
      Compliance(displayUnit="ml/mmHg") = 4.5003694550739e-08)                                                                                              annotation (
      Placement(visible = true, transformation(origin = {-70, 36}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Hydraulic.Components.ElasticVessel PulmonaryVeinE(Compliance = 6e-7, volume_start = 0.0004) annotation (
      Placement(visible = true, transformation(origin={32,32},    extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Hydraulic.Components.ElasticVessel SystemicVeinE(Compliance = 1.3e-5, volume_start = 0.0035) annotation (
      Placement(visible = true, transformation(origin={-72,-52},    extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Hydraulic.Components.ElasticVessel SystemicArteryE(Compliance = 7.5e-8, ZeroPressureVolume = 0, volume_start = 0.001) annotation (
      Placement(visible = true, transformation(origin={32,-52},    extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Hydraulic.Components.Pump rightHeart(useSolutionFlowInput = true) annotation (
      Placement(visible = true, transformation(origin = {-72, -12}, extent = {{-10, 10}, {10, -10}}, rotation = 90)));
    Physiolibrary.Hydraulic.Components.Pump leftHeart(useSolutionFlowInput = true) annotation (
      Placement(visible = true, transformation(origin = {32, -16}, extent = {{-10, 10}, {10, -10}}, rotation = -90)));
    Physiolibrary.Hydraulic.Components.Conductor SystemicConductance(
        Conductance=7.1255849705337e-09) annotation (Placement(visible=true,
          transformation(
          origin={-30,-52},
          extent={{-10,-10},{10,10}},
          rotation=180)));
    Physiolibrary.Types.Constants.VolumeFlowRateConst volumeFlowRate(k = 9.16667e-05) annotation (
      Placement(visible = true, transformation(origin = {-16, -8}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
  equation
    connect(volumeFlowRate.y, leftHeart.solutionFlow) annotation (
      Line(points={{-11,-8},{24,-8},{24,-16},{25,-16}},          color = {0, 0, 127}));
    connect(PulmonaryVeinE.q_in, leftHeart.q_in) annotation (
      Line(points={{32,32},{32,32},{32,-6}}));
    connect(SystemicArteryE.q_in, leftHeart.q_out) annotation (
      Line(points={{32,-52},{32,-52},{32,-26}}));
    connect(volumeFlowRate.y, rightHeart.solutionFlow) annotation (
      Line(points={{-11,-8},{-12.5,-8},{-12.5,-12},{-65,-12}},          color = {0, 0, 127}));
    connect(SystemicVeinE.q_in, rightHeart.q_in) annotation (
      Line(points={{-72,-52},{-72,-52},{-72,-22}}));
    connect(rightHeart.q_out, PulmonaryArtE.q_in) annotation (
      Line(points = {{-72, -2}, {-70, -2}, {-70, 36}}));
    connect(SystemicVeinE.q_in, SystemicConductance.q_out)
      annotation (Line(points={{-72,-52},{-40,-52}}));
    connect(SystemicConductance.q_in, SystemicArteryE.q_in)
      annotation (Line(points={{-20,-52},{32,-52}}));
    connect(PulmonaryConductance.q_out, PulmonaryVeinE.q_in)
      annotation (Line(points={{-20,36},{32,36},{32,32}}));
    connect(PulmonaryArtE.q_in, PulmonaryConductance.q_in)
      annotation (Line(points={{-70,36},{-40,36}}));
  end CVS;

  model O2
    Physiolibrary.Chemical.Components.Substance veins(solute_start(displayUnit = "mol") = 0.02, useNormalizedVolume = false)  annotation (
      Placement(visible = true, transformation(origin = {-72, -8}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Chemical.Components.Substance arteries(solute_start(displayUnit = "mol") = 0.02, useNormalizedVolume = false)  annotation (
      Placement(visible = true, transformation(origin = {70, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Chemical.Components.SolutePump tissues(SoluteFlow = 0.0003)  annotation (
      Placement(visible = true, transformation(origin={-36,-52},    extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Chemical.Components.Stream lungsStream(useSolutionFlowInput = true)  annotation (
      Placement(visible = true, transformation(origin = {-36, 34}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
    Physiolibrary.Chemical.Components.Stream tissuesStream(SolutionFlow = 1.66667e-05, useSolutionFlowInput = true)  annotation (
      Placement(visible = true, transformation(origin = {22, -32}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
    Physiolibrary.Chemical.Components.Stream lungsOutStream(useSolutionFlowInput = true)  annotation (
      Placement(visible = true, transformation(origin={22,36},    extent = {{-10, 10}, {10, -10}}, rotation = 0)));
    Physiolibrary.Chemical.Sources.UnlimitedSolutionStorage tissuesSpace annotation (
      Placement(visible = true, transformation(origin={-10,-50},    extent = {{-10, -10}, {10, 10}}, rotation=180)));
    Physiolibrary.Chemical.Sources.UnlimitedSolutePump lungsSolute(SoluteFlow = 0.0007)  annotation (
      Placement(visible = true, transformation(origin={4,56},    extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Physiolibrary.Chemical.Sources.UnlimitedSolutionStorage unlimitedSolutionStorage1(Conc = 1)  annotation (
      Placement(visible = true, transformation(origin = {-14, 35}, extent = {{6, -7}, {-6, 7}}, rotation = 0)));
  Physiolibrary.Types.Constants.VolumeFlowRateConst volumeFlowRate(k = 9.16667e-05)  annotation (
      Placement(visible = true, transformation(origin={-44,-4},    extent = {{-4, -4}, {4, 4}}, rotation = 0)));
  Physiolibrary.Types.Constants.VolumeConst volumeVeins(k = 0.0035)  annotation (
      Placement(visible = true, transformation(origin={-94,-4},    extent = {{-4, -4}, {4, 4}}, rotation = 0)));
  Physiolibrary.Types.Constants.VolumeConst volumeArteris(k = 0.0015)  annotation (
      Placement(visible = true, transformation(origin = {42, -8}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
  equation
    connect(volumeVeins.y, veins.solutionVolume) annotation (
      Line(points={{-89,-4},{-82,-4},{-76,-4}},                   color = {0, 0, 127}));
    connect(veins.q_out, lungsStream.q_in) annotation (
      Line(points = {{-72, -8}, {-72, 34}, {-46, 34}}, color = {107, 45, 134}));
    connect(tissuesStream.q_out, veins.q_out) annotation (
      Line(points={{12,-32},{-72,-32},{-72,-8},{-72,-8}},          color = {107, 45, 134}));
    connect(volumeArteris.y, arteries.solutionVolume) annotation (
      Line(points={{47,-8},{66,-8},{66,-6},{66,-6}},          color = {0, 0, 127}));
    connect(volumeFlowRate.y, lungsOutStream.solutionFlow) annotation (
      Line(points={{-39,-4},{22,-4},{22,29}},                  color = {0, 0, 127}));
    connect(volumeFlowRate.y, tissuesStream.solutionFlow) annotation (
      Line(points={{-39,-4},{22,-4},{22,-25}},                   color = {0, 0, 127}));
    connect(volumeFlowRate.y, lungsStream.solutionFlow) annotation (
      Line(points={{-39,-4},{-36,-4},{-36,22},{-36,27}},                                color = {0, 0, 127}));
    connect(lungsSolute.q_out, lungsOutStream.q_in) annotation (
      Line(points={{4,46},{4,36},{12,36}},        color = {107, 45, 134}));
    connect(lungsOutStream.q_out, arteries.q_out) annotation (
      Line(points={{32,36},{70,36},{70,-10}},        color = {107, 45, 134}));
    connect(unlimitedSolutionStorage1.q_out, lungsStream.q_out) annotation (
      Line(points = {{-20, 35}, {-26, 35}, {-26, 34}}, color = {107, 45, 134}));
    connect(tissues.q_in, tissuesStream.q_out) annotation (
      Line(points={{-46,-52},{-52,-52},{-52,-32},{12,-32}},                     color = {107, 45, 134}));
    connect(tissues.q_out, tissuesSpace.q_out) annotation (
      Line(points={{-26,-52},{-24,-50},{-20,-50}},                           color = {107, 45, 134}));
    connect(arteries.q_out, tissuesStream.q_in) annotation (
      Line(points = {{70, -10}, {70, -10}, {70, -32}, {32, -32}, {32, -32}}, color = {107, 45, 134}));
  end O2;

  model O2_bus
    Physiolibrary.Chemical.Components.Substance veins(solute_start(displayUnit = "mol") = 0.02, useNormalizedVolume = false) annotation (
      Placement(visible = true, transformation(origin = {-72, -8}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Chemical.Components.Substance arteries(solute_start(displayUnit = "mol") = 0.02, useNormalizedVolume = false) annotation (
      Placement(visible = true, transformation(origin = {70, -10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Chemical.Components.SolutePump tissues(SoluteFlow = 0.0003) annotation (
      Placement(visible = true, transformation(origin = {-14, -48}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Chemical.Components.Stream lungsStream(useSolutionFlowInput = true) annotation (
      Placement(visible = true, transformation(origin = {-36, 34}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
    Physiolibrary.Chemical.Components.Stream tissuesStream(SolutionFlow = 1.66667e-05, useSolutionFlowInput = true) annotation (
      Placement(visible = true, transformation(origin = {22, -32}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
    Physiolibrary.Chemical.Components.Stream lungsOutStream(useSolutionFlowInput = true) annotation (
      Placement(visible = true, transformation(origin = {30, 32}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
    Physiolibrary.Chemical.Sources.UnlimitedSolutionStorage tissuesSpace annotation (
      Placement(visible = true, transformation(origin = {-32, -90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Chemical.Sources.UnlimitedSolutePump lungsSolute(SoluteFlow = 0.0007) annotation (
      Placement(visible = true, transformation(origin = {4, 76}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Physiolibrary.Chemical.Sources.UnlimitedSolutionStorage unlimitedSolutionStorage1(Conc = 1) annotation (
      Placement(visible = true, transformation(origin = {-14, 35}, extent = {{6, -7}, {-6, 7}}, rotation = 0)));
    Physiolibrary.Types.Constants.VolumeFlowRateConst volumeFlowRate(k = 9.16667e-05) annotation (
      Placement(visible = true, transformation(origin = {-36, -4}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
    Physiolibrary.Types.Constants.VolumeConst volumeArteris(k = 0.0015) annotation (
      Placement(visible = true, transformation(origin = {42, -8}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
  Physiolibrary.Types.BusConnector busConnector1 annotation (
      Placement(visible = true, transformation(origin = {-80, 80}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-84, 88}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  equation
    connect(veins.solutionVolume, busConnector1.VenousVolume) annotation (
      Line(points = {{-76, -4}, {-88, -4}, {-88, 80}, {-80, 80}}, color = {0, 0, 127}));
    connect(veins.q_out, lungsStream.q_in) annotation (
      Line(points = {{-72, -8}, {-72, 34}, {-46, 34}}, color = {107, 45, 134}));
    connect(tissuesStream.q_out, veins.q_out) annotation (
      Line(points = {{12, -32}, {-74, -32}, {-74, -8}, {-72, -8}}, color = {107, 45, 134}));
    connect(volumeArteris.y, arteries.solutionVolume) annotation (
      Line(points={{47,-8},{66,-8},{66,-6},{66,-6}},          color = {0, 0, 127}));
    connect(volumeFlowRate.y, lungsOutStream.solutionFlow) annotation (
      Line(points={{-31,-4},{30,-4},{30,25},{30,25}},          color = {0, 0, 127}));
    connect(volumeFlowRate.y, tissuesStream.solutionFlow) annotation (
      Line(points={{-31,-4},{22,-4},{22,-25},{22,-25}},          color = {0, 0, 127}));
    connect(volumeFlowRate.y, lungsStream.solutionFlow) annotation (
      Line(points={{-31,-4},{-28,-4},{-28,24},{-36,24},{-36,27},{-36,27}},              color = {0, 0, 127}));
    connect(lungsSolute.q_out, lungsOutStream.q_in) annotation (
      Line(points = {{4, 66}, {4, 32}, {20, 32}}, color = {107, 45, 134}));
    connect(lungsOutStream.q_out, arteries.q_out) annotation (
      Line(points = {{40, 32}, {70, 32}, {70, -10}}, color = {107, 45, 134}));
    connect(unlimitedSolutionStorage1.q_out, lungsStream.q_out) annotation (
      Line(points = {{-20, 35}, {-26, 35}, {-26, 34}}, color = {107, 45, 134}));
    connect(tissues.q_in, tissuesStream.q_out) annotation (
      Line(points = {{-24, -48}, {-34, -48}, {-34, -32}, {12, -32}, {12, -32}}, color = {107, 45, 134}));
    connect(tissues.q_out, tissuesSpace.q_out) annotation (
      Line(points = {{-4, -48}, {2, -48}, {2, -90}, {-22, -90}, {-22, -90}}, color = {107, 45, 134}));
    connect(arteries.q_out, tissuesStream.q_in) annotation (
      Line(points = {{70, -10}, {70, -10}, {70, -32}, {32, -32}, {32, -32}}, color = {107, 45, 134}));
  end O2_bus;

  model CVS_bus
    Physiolibrary.Hydraulic.Components.Resistor PulmonaryResistance(Resistance = 6.9e-8, useConductanceInput = false) annotation (
      Placement(visible = true, transformation(origin = {-28, 34}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Hydraulic.Components.ElasticVessel PulmonaryArtE(Compliance(displayUnit = "m3/Pa") = 5e-8, ZeroPressureVolume = 0, volume_start = 0.0001) annotation (
      Placement(visible = true, transformation(origin = {-70, 36}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Hydraulic.Components.ElasticVessel PulmonaryVeinE(Compliance = 6e-7, volume_start = 0.0004) annotation (
      Placement(visible = true, transformation(origin = {28, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Hydraulic.Components.ElasticVessel SystemicVeinE(Compliance = 1.3e-5, volume_start = 0.0035) annotation (
      Placement(visible = true, transformation(origin = {-70, -60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Hydraulic.Components.ElasticVessel SystemicArteryE(Compliance = 7.5e-8, ZeroPressureVolume = 0, volume_start = 0.001) annotation (
      Placement(visible = true, transformation(origin = {34, -54}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Physiolibrary.Hydraulic.Components.Pump rightHeart(useSolutionFlowInput = true) annotation (
      Placement(visible = true, transformation(origin = {-72, -12}, extent = {{-10, 10}, {10, -10}}, rotation = 90)));
    Physiolibrary.Hydraulic.Components.Pump leftHeart(useSolutionFlowInput = true) annotation (
      Placement(visible = true, transformation(origin = {32, -16}, extent = {{-10, 10}, {10, -10}}, rotation = -90)));
    Physiolibrary.Hydraulic.Components.Resistor SystemicResistance(Resistance(displayUnit = "(Pa.s)/m3") = 7.1e-9) annotation (
      Placement(visible = true, transformation(origin = {-14, -52}, extent = {{-10, -10}, {10, 10}}, rotation = 180)));
    Physiolibrary.Types.Constants.VolumeFlowRateConst volumeFlowRate(k = 9.16667e-05) annotation (
      Placement(visible = true, transformation(origin = {-16, -8}, extent = {{-4, -4}, {4, 4}}, rotation = 0)));
  Physiolibrary.Types.BusConnector busConnector1 annotation (
      Placement(visible = true, transformation(origin = {-78, 78}, extent = {{-20, -20}, {20, 20}}, rotation = 0), iconTransformation(origin = {-84, 82}, extent = {{-20, -20}, {20, 20}}, rotation = 0)));
  equation
    connect(SystemicVeinE.volume, busConnector1.VenousVolume) annotation (
      Line(points = {{-64, -70}, {-92, -70}, {-92, 78}, {-78, 78}, {-78, 78}}, color = {0, 0, 127}));
    connect(volumeFlowRate.y, leftHeart.solutionFlow) annotation (
      Line(points={{-11,-8},{24,-8},{24,-16},{25,-16}},          color = {0, 0, 127}));
    connect(PulmonaryVeinE.q_in, leftHeart.q_in) annotation (
      Line(points = {{28, 30}, {32, 30}, {32, -6}}));
    connect(SystemicArteryE.q_in, leftHeart.q_out) annotation (
      Line(points = {{34, -54}, {32, -54}, {32, -26}}));
    connect(volumeFlowRate.y, rightHeart.solutionFlow) annotation (
      Line(points = {{-11, -8}, {-50.5, -8}, {-50.5, -12}, {-65, -12}}, color = {0, 0, 127}));
    connect(SystemicVeinE.q_in, rightHeart.q_in) annotation (
      Line(points = {{-70, -60}, {-72, -60}, {-72, -22}}));
    connect(rightHeart.q_out, PulmonaryArtE.q_in) annotation (
      Line(points = {{-72, -2}, {-70, -2}, {-70, 36}}));
    connect(SystemicVeinE.q_in, SystemicResistance.q_out) annotation (
      Line(points = {{-70, -60}, {-24, -60}, {-24, -52}, {-24, -52}}));
    connect(SystemicResistance.q_in, SystemicArteryE.q_in) annotation (
      Line(points = {{-4, -52}, {34, -52}, {34, -54}, {34, -54}}));
    connect(PulmonaryResistance.q_out, PulmonaryVeinE.q_in) annotation (
      Line(points = {{-18, 34}, {28, 34}, {28, 30}, {28, 30}}));
    connect(PulmonaryArtE.q_in, PulmonaryResistance.q_in) annotation (
      Line(points = {{-70, 36}, {-38, 36}, {-38, 34}, {-38, 34}}));
  end CVS_bus;

  model total_model
    CVS_bus cVS_bus1 annotation (
      Placement(visible = true, transformation(origin = {6, 8}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    O2_bus o2_bus1 annotation (
      Placement(visible = true, transformation(origin={-52,8},    extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(o2_bus1.busConnector1, cVS_bus1.busConnector1) annotation (
      Line(points={{-60.4,16.8},{-2,16.8},{-2,16.2},{-2.4,16.2}},
                                                               color = {0, 0, 255}));

  end total_model;
  annotation (
    uses(Physiolibrary(version = "2.3.1"), Modelica(version="3.2.1")));
end PhysioSystem;
